@@ -12,32 +12,37 @@ microarraydata <- function(file, check = TRUE,
     {
       # check argument file
       if (!is.character(file))
-        stop("The argument file must be a character string")
+        stop("The argument file must be a character string.")
       le.file <- nchar(file)
       suffix <- substr(file, le.file - 3, le.file)
       if (suffix != ".txt")
-        stop("The argument file must be a character string ending by .txt")
+        stop("The argument file must be a character string ending by .txt.")
     }
     d <- read.table(file, header = FALSE)
   }  
   nrowd <- nrow(d)
   ncold <- ncol(d)
   data <- as.matrix(d[2:nrowd, 2:ncold]) 
-  if (any(data > 100))
-    warning("Your data contain high values (> 100). 
-            Make sure that your data (microarray signal) are in log-scale.\n") 
-  if (nrowd < 100)
-    warning("Your dataset contains less than 100 lines. Are you sure you really
-            work on microarray data ? This function should
-            not be used with another type of data.")
+
+    if(any(!complete.cases(data)))
+    stop("microarraydata() should not be used with data including NA values.")
   
   if (check)
-  {
+  {  
+    if (any(data > 100))
+    warning(strwrap(prefix = "\n", initial = "\n",
+                    "Your data contain high values (> 100). 
+      Make sure that your data (microarray signal) are in log-scale.\n"))
+    if (nrowd < 100)
+      warning(strwrap(prefix = "\n", initial = "\n",
+                      "Your dataset contains less than 100 lines. Are you sure you really
+      work on microarray data ? This function should
+      not be used with another type of data."))
+    
     # check that doses and responses are numeric
     if (!is.numeric(as.matrix(d[,2:ncold])))
       stop("All the columns except the first one must be numeric with the numeric 
-           dose in the firt line and the numeric response of each item in the other
-           lines.")
+      dose in the firt line and the numeric response of each item in the other lines.")
   }
   
   # Normalization using limma
@@ -53,14 +58,19 @@ microarraydata <- function(file, check = TRUE,
   (nitems <- nrow(data))
   
   # control of the design
+  if (any(dose < 0))
+    stop("DRomics cannot be used with negative values of doses.")
   design <- table(dose, dnn = "")
-  if (length(design) < 4)
+  nbdoses <- length(design)
+  nbpts <- sum(design)
+  if ((nbdoses < 4)| (nbpts < 8))
     stop("Dromics cannot be used with a dose-response design 
-         with less than four tested doses/concentrations")
-  if (length(design) == 4)
-    warning("When using DRomics with a dose-response design with only four tested doses/concentrations, 
-            it is recommended to check after the modelling step that all selected models have no more 
-            than 4 parameters")  
+    with less than four tested doses/concentrations or less than eight data points
+         per dose-response curve.")
+  if (nbdoses < 6)
+    warning(strwrap(prefix = "\n", initial = "\n",
+      "To optimize the dose-response modelling, it is recommended to use
+      a dose-response design with at least six different tested doses."))
   
   fdose <- as.factor(dose)
   tdata <- t(data)
@@ -74,7 +84,8 @@ microarraydata <- function(file, check = TRUE,
   
   reslist <- list(data = data, dose = dose, item = item, 
                   design = design, data.mean = data.mean, 
-                  norm.method = norm.method, data.beforenorm = data.beforenorm)  
+                  norm.method = norm.method, data.beforenorm = data.beforenorm,
+                  containsNA = FALSE)  
   
   return(structure(reslist, class = "microarraydata"))
 }
@@ -83,12 +94,12 @@ microarraydata <- function(file, check = TRUE,
 print.microarraydata <- function(x, ...)
 {
   if (!inherits(x, "microarraydata"))
-    stop("Use only with 'microarraydata' objects")
+    stop("Use only with 'microarraydata' objects.")
   
-  cat("Elements of the experimental design in order to check the coding of the data :\n")
+  cat("Elements of the experimental design in order to check the coding of the data:\n")
   cat("Tested doses and number of replicates for each dose:\n")
   print(x$design)
-  cat("Number of items: ", length(x$item),"\n")
+  cat("Number of items:", length(x$item), "\n")
   
   if (length(x$item) > 20)
   {
@@ -100,13 +111,13 @@ print.microarraydata <- function(x, ...)
     print(x$item)
   }
   if (x$norm.method != "none")
-    cat("Data were normalized between arrays using the following method: ", x$norm.method," \n")
+    cat("Data were normalized between arrays using the following method:", x$norm.method, "\n")
 }
 
 plot.microarraydata <- function(x, ...) 
 {
   if (!inherits(x, "microarraydata"))
-    stop("Use only with 'microarraydata' objects")
+    stop("Use only with 'microarraydata' objects.")
 
   def.par <- par(no.readonly = TRUE)
   if (x$norm.method != "none")
